/*
    TinyMCE styles for TailorDev CMS
 */

@import "mixins";

p {
    width: 100%;

    &.p_small {
        font-size: 0.8em;
    }

    &.p_caption {
        @include clearfix;
        margin-left: auto;
        margin-right: auto;
        width: 60%;
        font-style: italic;
    }

    &.clearfix {
        @include clearfix;
    }

    &.code {
        font-family: Pragmata, Menlo, 'DejaVu LGC Sans Mono', 'DejaVu Sans Mono', Consolas, 'Everson Mono', 'Lucida Console', 'Andale Mono', 'Nimbus Mono L', 'Liberation Mono', FreeMono, 'Osaka Monospaced', Courier, 'New Courier', monospace;
    }

    & > img.img_block {
        margin-left: auto;
        margin-right: auto;
    }
}

img {
    &.img_left {
        float: left;
        margin-right: 0.2em;
    }

    &.img_right {
        float: right;
        margin-left: 0.2em;
    }

    &.img_block {
        @include clearfix;
        display: block;
        padding: 0.2em;
    }
}
