{% load i18n %}
{% load fb_versions %}
{% load td_cms_tags %}

<!-- Header -->
<header>
    <hgroup>
        <h1>{{ page.title }}</h1>
    </hgroup>
</header>
<!-- /Header -->

{% if page.image %}
    <div class="page-image-wrapper">
        <img src="{% version page.image 'large' %}" alt="{{ page.title }}" class="page-image"/>
    </div>
{% endif %}

{% if page.synopsis %}
<div class="page-synopsis">
    {% if page.synopsis %}
    <p>
        {{ page.synopsis|safe }}
    </p>
    {% endif %}
</div>
{% endif %}

<div class="page-content">
    {% if page.content %}
    <p>
        {{ page.content|safe }}
    </p>
    {% endif %}
</div>

<div class="page-date">
    {% trans "Last modified:" %} {{ page.last_modified|date:"SHORT_DATE_FORMAT" }}
</div>

{% if page.allow_comments %}
<div class="page-comments">
    <h2>{% trans "Comments" %}</h2>
    {% show_disqus_thread %}
</div>
{% endif %}
