{% extends "td_cms/layouts/two_cols_left_sidebar.html" %}

{% load staticfiles %}

{% block css %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static "td_cms/css/styles.css" %}" />
{% endblock %}

{% block page_title %}{{ category.name }}{% endblock page_title %}
{% block page_class %}page{% endblock page_class %}

{# Google #}
{% block meta_description %}{{ category.short_description|striptags|safe }}{% endblock meta_description %}
{% block meta_keywords %}{{ category.name }}{% endblock meta_keywords %}
{% block application_name %}TailorDev CMS{% endblock application_name %}

{# Facebook #}
{% block facebook_title %}{{ category.name }}{% endblock facebook_title %}
{% block facebook_type %}Article{% endblock facebook_type %}
{% block facebook_url %}{{ request.build_absolute_uri }}{% endblock facebook_url %}
{% block facebook_description %}{{ category.short_description|striptags|safe }}{% endblock facebook_description %}

{# Twitter #}
{% block twitter_title %}{{ category.name }}{% endblock twitter_title %}
{% block twitter_description %}{{ category.short_description|striptags|safe }}{% endblock twitter_description %}

{% block left_sidebar_class %}{% endblock left_sidebar_class %}

{% block left_sidebar %}
    {% include "td_cms/partials/sidebar/category_list.html" %}
    {% include "td_cms/partials/sidebar/top_articles_list.html" %}
{% endblock left_sidebar %}

{% block main_content_class %}category-detail{% endblock main_content_class %}

{% block main_content %}
    {% include "td_cms/partials/main_content/category_detail.html" %}
{% endblock main_content %}
