{% if is_paginated %}
<div class="pagination-centered">

    <ul class="pagination">
        {% if page_obj.has_previous %}
        <li class="arrow"><a href="?page={{ page_obj.previous_page_number }}" class="pagination">&laquo;</a></li>
        {% endif %}
        <li class="current">
            <a href="">{{ page_obj.number }}</a>
            {{ page_obj.start_index }} - {{ page_obj.end_index }}</li>
        {% if page_obj.has_next %}
        <li class="arrow"><a href="?page={{ page_obj.next_page_number }}" class="pagination">&raquo;</a></li>
        {% endif %}
    </ul>
</div>
{% endif %}
