{% load i18n %}

{% if disqus_shortname %}
<!-- Disqus Thead -->
<div id="disqus_thread"></div>
<script type="text/javascript">
    /* * * CONFIGURATION VARIABLES * * */
    var disqus_shortname = '{{ disqus_shortname }}';
    var disqus_identifier = '{{ page.id }}-{{ page.slug }}';
    var disqus_title = '{{ page.title }}';

    /* * * DON'T EDIT BELOW THIS LINE * * */
    (function() {
        var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;
        dsq.src = '//' + disqus_shortname + '.disqus.com/embed.js';
        (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);
    })();
</script>
<noscript>
    {% blocktrans %}
    Please enable JavaScript to view the <a href="http://disqus.com/?ref_noscript">comments powered by Disqus.</a>
    {% endblocktrans %}
</noscript>
<a href="http://disqus.com" class="dsq-brlink">
    Comments powered by <span class="logo-disqus">Disqus</span>
</a>
<!-- ./Disqus Thead -->
{% endif %}
