{% comment %}
    Feel free to override this template to add your own social sharing plugin
{% endcomment %}
{% load i18n %}

<div class="page-social">

    <a class="medium button dropdown share" data-dropdown="share-list" href="#">
        {% trans "Share this" %}
    </a>

    <ul id="share-list" class="f-dropdown">
        {% with  title=page.title|urlencode|iriencode url=request.build_absolute_uri|urlencode media=page.get_image_full_url|urlencode %}

        <li>
            <a href="http://www.facebook.com/share.php?u={{ url }}" target="_blank">
                <i class="social facebook"></i>
                Facebook
            </a>
        </li>
        <li>
            <a href="http://twitter.com/home?status={{ title }}+{{ url }}" target="_blank">
                <i class="social twitter"></i>
                Twitter
            </a>
        </li>
        <li>
            <a href="http://pinterest.com/pin/create/button/?url={{ url }}&amp;media={{ media }}&amp;description={{ title }}" target="_blank">
                <i class="social pinterest"></i>
                Pinterest
            </a>
        </li>
        <li>
            <a href="http://plus.google.com/share?url={{ url }}" target="_blank">
                <i class="social google-plus"></i>
                Google+
            </a>
        </li>
        <li>
            <a href="http://www.linkedin.com/shareArticle?mini=true&amp;url={{ url }}&amp;title={{ title }}&amp;source={{ url }}" target="_blank">
                <i class="social linkedin"></i>
                LinkedIn
            </a>
        </li>
        {% endwith %}
    </ul>

</div> <!--/.page-social-->
