/*
    TailorDev CMS Styles
*/
/*
    TinyMCE styles for TailorDev CMS
 */
/*
    Scss mixins for TailorDev CMS
 */
/* line 7, ../scss/_tinymce.scss */
p {
  width: 100%;
}
/* line 10, ../scss/_tinymce.scss */
p.p_small {
  font-size: 0.8em;
}
/* line 14, ../scss/_tinymce.scss */
p.p_caption {
  margin-left: auto;
  margin-right: auto;
  width: 60%;
  font-style: italic;
}
/* line 7, ../scss/_mixins.scss */
p.p_caption:before, p.p_caption:after {
  content: "";
  display: table;
}
/* line 12, ../scss/_mixins.scss */
p.p_caption:after {
  clear: both;
}
/* line 7, ../scss/_mixins.scss */
p.clearfix:before, p.clearfix:after {
  content: "";
  display: table;
}
/* line 12, ../scss/_mixins.scss */
p.clearfix:after {
  clear: both;
}
/* line 26, ../scss/_tinymce.scss */
p.code {
  font-family: Pragmata, Menlo, 'DejaVu LGC Sans Mono', 'DejaVu Sans Mono', Consolas, 'Everson Mono', 'Lucida Console', 'Andale Mono', 'Nimbus Mono L', 'Liberation Mono', FreeMono, 'Osaka Monospaced', Courier, 'New Courier', monospace;
}
/* line 30, ../scss/_tinymce.scss */
p > img.img_block {
  margin-left: auto;
  margin-right: auto;
}

/* line 37, ../scss/_tinymce.scss */
img.img_left {
  float: left;
  margin-right: 0.2em;
}
/* line 42, ../scss/_tinymce.scss */
img.img_right {
  float: right;
  margin-left: 0.2em;
}
/* line 47, ../scss/_tinymce.scss */
img.img_block {
  display: block;
  padding: 0.2em;
}
/* line 7, ../scss/_mixins.scss */
img.img_block:before, img.img_block:after {
  content: "";
  display: table;
}
/* line 12, ../scss/_mixins.scss */
img.img_block:after {
  clear: both;
}
